Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(347)

Unified Diff: chrome/browser/resources/options/options_page.js

Issue 11854012: Rename options.OptionsBubble to cr.ui.AutoCloseBubble (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Remove obsoleted CSS declaration. Created 7 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/resources/options/options_page.css ('k') | chrome/browser/resources/shared/css/bubble.css » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/resources/options/options_page.js
diff --git a/chrome/browser/resources/options/options_page.js b/chrome/browser/resources/options/options_page.js
index b2c1c052092e542238d37c25257c01342f91574a..958e06efa66cfaf55d1a7f6eca62497b671fad6a 100644
--- a/chrome/browser/resources/options/options_page.js
+++ b/chrome/browser/resources/options/options_page.js
@@ -408,7 +408,7 @@ cr.define('options', function() {
/**
* Returns the currently visible bubble, or null if no bubble is visible.
* @return {OptionsBubble} The bubble currently being shown.
*/
OptionsPage.getVisibleBubble = function() {
var bubble = OptionsPage.bubble_;
@@ -428,7 +428,7 @@ cr.define('options', function() {
OptionsPage.showBubble = function(content, target, domSibling, location) {
OptionsPage.hideBubble();
- var bubble = new options.OptionsBubble;
+ var bubble = new cr.ui.AutoCloseBubble;
bubble.anchorNode = target;
bubble.domSibling = domSibling;
bubble.arrowLocation = location;
@@ -408,7 +408,7 @@ cr.define('options', function() {
/**
* Returns the currently visible bubble, or null if no bubble is visible.
- * @return {OptionsBubble} The bubble currently being shown.
+ * @return {AutoCloseBubble} The bubble currently being shown.
*/
OptionsPage.getVisibleBubble = function() {
« no previous file with comments | « chrome/browser/resources/options/options_page.css ('k') | chrome/browser/resources/shared/css/bubble.css » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698